@@ -20,9 +20,9 @@
     pipelka@teleweb.at 
   
     Last Update:      $Author: braindead $ 
-    Update Date:      $Date: 2004/02/21 10:11:15 $ 
+    Update Date:      $Date: 2004/09/05 10:51:41 $ 
     Source File:      $Source: /cvsroot/paragui/paragui/include/pgimage.h,v $ 
-    CVS/RCS Revision: $Revision: 1.3.6.1.2.2 $ 
+    CVS/RCS Revision: $Revision: 1.3.6.1.2.5 $ 
     Status:           $State: Exp $ 
 */
 
@@ -38,50 +38,78 @@
 /**
 	@author Jaroslav Vozab 
  
-	@short A static (non-resizeable) frame with image. 
+	@short A static (non-resizeable by the end user) frame with image. 
 */
 
 class DECLSPEC PG_Image : public PG_ThemeWidget  {
 public:
 	/**
-	Contructor of the PG_Image class (loading from file)
+	@short Contructor of the PG_Image class (loading from file)
+
+	Creates the widget and loads the image from a file
+
 	@param parent	pointer to the parent widget or NULL
 	@param p			position of the PG_Image widget
 	@param filename	image-file to load
 	@param style		widgetstyle to use
-	This constructor creates the widget and loads the image from a file
+
 	*/
-	PG_Image(PG_Widget* parent, const PG_Point& p, const char* filename, const char* style = "ThemeWidget");
+	PG_Image(PG_Widget* parent, const PG_Point& p, const char* filename, Uint8 drawmode = BKMODE_TILE, const char* style = "ThemeWidget");
 
 	/**
-	Contructor of the PG_Image class (image from surface)
+	@short Contructor of the PG_Image class (image from surface)
+
+	Creates the widget and loads the image from an SDL_Surface	
+
 	@param parent		pointer to the parent widget or NULL
 	@param p				position of the PG_Image widget
 	@param image		pointer to imagedata (SDL_Surface)
 	@param freeimage	if true the imagedata is handled by the widget
 	@param style		widgetstyle to use
 	*/
-	PG_Image(PG_Widget* parent, const PG_Point& p, SDL_Surface* image, bool freeimage = true, const char* style = "ThemeWidget");
+	PG_Image(PG_Widget* parent, const PG_Point& p, SDL_Surface* image, bool freeimage = true, Uint8 drawmode = BKMODE_TILE, const char* style = "ThemeWidget");
 
 	/**
-	Contructor of the PG_Image class (loading from file)
+	@short Contructor of the PG_Image class (loading from file)
+
+	Creates the widget and loads the image from a file using a colorkey
+
 	@param parent	pointer to the parent widget or NULL
 	@param p		position of the PG_Image widget
 	@param filename	image-file to load
 	@param	colorkey	colorkey (0xRRGGBB)
 	@param style		widgetstyle to use
-	This constructor creates the widget and loads the image from a file using a colorkey.
+
 	*/
-	PG_Image(PG_Widget* parent, const PG_Point& p, const char* filename, Uint32 colorkey, const char* style);
+	PG_Image(PG_Widget* parent, const PG_Point& p, const char* filename, Uint32 colorkey, Uint8 drawmode = BKMODE_TILE, const char* style = "ThemeWidget");
 
 	/**
-	Set the colorkey of the image
+	@short Set the colorkey of the image
+
 	@param key		colorkey (0xRRGGBB);
 	*/
 	void SetColorKey(Uint32 key);
 	
+	/**
+	@ Set mode of drawing (BKMODE_TILE | BKMODE_STRETCH | BKMODE_3TILEH | BKMODE_3TILEV | BKMODE_9TILE)
+	*/
+	void SetDrawMode(Uint8 mode);
+
+	Uint8 GetDrawMode() {
+		return my_DrawMode;
+	};
+
+	bool LoadImage(const char* filename);
+	bool LoadImage(const char* filename, Uint32 key);
+	bool SetImage(SDL_Surface* image, bool bFreeImage = true);
+
+	~PG_Image();
+	
 protected:
 
+	Uint8 my_DrawMode;
+	SDL_Surface* my_cachedSrf;
+	
 	/** */
 	void eventDraw(SDL_Surface* surface, const PG_Rect& rect);
 
