@@ -20,9 +20,9 @@
     pipelka@teleweb.at
  
     Last Update:      $Author: braindead $
-    Update Date:      $Date: 2004/03/01 20:51:40 $
+    Update Date:      $Date: 2004/09/05 10:51:41 $
     Source File:      $Source: /cvsroot/paragui/paragui/include/pgwidget.h,v $
-    CVS/RCS Revision: $Revision: 1.3.6.3.2.10 $
+    CVS/RCS Revision: $Revision: 1.3.6.3.2.17 $
     Status:           $State: Exp $
 */
 
@@ -32,6 +32,7 @@
 #include "pgmessageobject.h"
 #include "pgrectlist.h"
 #include "pgfont.h"
+#include "pgstring.h"
 
 #include MAP_INC
 
@@ -171,6 +172,7 @@ public:
 	Move and resize widget
 
 	@param r	new widget rectangle (client coordinates)
+	@param update	is the update true
 	@return		function succeeded
 
 	This function moves and resizes the widget to fit the given rectangle.
@@ -214,13 +216,6 @@ public:
 	*/
 	SDL_Surface* GetWidgetSurface();
 
-	/**
-	Return the pointer to the screen surface
-
-	@return	SDL_Surface pointer to the screen surface
-	*/
-	//SDL_Surface* GetScreenSurface();
-
 	/**
 	Check if the object is visible
 	@return							true if object is visible
@@ -248,7 +243,8 @@ public:
 	@param bModal set to true if processing takes place in a modal loop
 	@return	true if the event was sucessfully processed
 
-	ProcessEvent asks the widget to process a given event.
+	ProcessEvent asks the widget to process a given event. It also asks its
+    parent and, if bModal is true, its children.
 	*/
 	virtual bool ProcessEvent(const SDL_Event* event, bool bModal = false);
 
@@ -405,7 +401,7 @@ public:
 	void MoveRect(int x, int y);
 
 	/** */
-	static void BulkUpdate();
+	//static void BulkUpdate();
 
 	/** */
 	static void BulkBlit();
@@ -535,7 +531,7 @@ public:
 	Set font color
 	@param	Color PG_Color class contains color information (RGB)
 	*/
-	void SetFontColor(const PG_Color& Color);
+	void SetFontColor(const PG_Color& Color, bool bRecursive = false);
 
 	/**
 	Set font transparency (!!!)
@@ -546,7 +542,7 @@ public:
 
 	/**
 	Set font style
-	@param	Style	Binary combination (OR) of PG_FSTYLE_NORMAL, PG_FSTYLE_BOLD, PG_FSTYLE_ITALIC and PG_FSTYLE_UNDERLINE
+	@param	Style	Binary combination (OR) of PG_Font::NORMAL, PG_Font::BOLD, PG_Font::ITALIC and PG_Font::UNDERLINE
 	@param	bRecursive alter all child widgets
 	*/
 	void SetFontStyle(PG_Font::Style Style, bool bRecursive = false);
@@ -644,6 +640,7 @@ public:
 	/**
 	Set the transparency of the drawing object
 	@param	t						transparency (0 - opaque / 255 - fully transparent)
+	@param	bRecursive	are transparency changes recursive
 	*/
 	virtual void SetTransparency(Uint8 t, bool bRecursive = false);
 
@@ -695,7 +692,7 @@ public:
 	/**
 	Enter modal mode
 	*/
-	virtual void RunModal();
+	virtual int RunModal();
 
 	/**
 	Quit modal mode
@@ -738,6 +735,15 @@ public:
 	
 	bool IsHidden();
 
+	/**
+		Set the return status of the modal eventloop.
+		@param status returnstatus
+		The specified status will be returned by the RunModal method
+	*/
+	void SetModalStatus(int status);
+	
+	void EnableReceiver(bool enable, bool bRecursive = false);
+
 protected:
 
 	/**
@@ -853,7 +859,7 @@ protected:
 	/**
 	text attached to the widget
 	*/
-	string my_text;
+	PG_String my_text;
 
 	/**
 	array of border colors
@@ -865,7 +871,7 @@ private:
 	PG_Widget(const PG_Widget&);
 	PG_Widget& operator=(const PG_Widget&);
 
-	static bool bBulkUpdate;
+	//static bool bBulkUpdate;
 	static int my_ObjectCounter;
 	static PG_RectList widgetList;
 
